﻿using CommunityToolkit.Maui.Core.Primitives;
using Model.Serialization;
using Model.Stub;

namespace Linaris;

public partial class App : Application
{
    private Manager manager = new(new LinqXmlSerialization(FileSystem.Current.AppDataDirectory));

    public Manager Manager
    {
        get => manager;
        set
        {
            manager = value;
        }
    }

    private FooterPage footerPage;

    public FooterPage FooterPage
    {
        get => footerPage;
        set
        {
            footerPage = value;
        }
    }

    private TimeSpan musicPosition = TimeSpan.FromSeconds(0);

    public TimeSpan MusicPosition
    {
        get => musicPosition;
        set
        {
            musicPosition = value;
        }
    }

    private MediaElementState mediaState = MediaElementState.Paused;

    public MediaElementState MediaState
    {
        get => mediaState;
        set
        {
            mediaState = value;
        }
    }


    public App()
    {
        InitializeComponent();
        footerPage = new FooterPage();
        MainPage = new AppShell();
    }

    protected override Window CreateWindow(IActivationState activationState)
    {

        var Window = base.CreateWindow(activationState);

        Window.Destroying += (sender, eventArgs) =>
        {
            Manager.SaveSerialization();
        };

        Window.Stopped += (sender, eventArgs) =>
        {
            Manager.SaveSerialization();
        };

        const int newHeight = 900;
        const int newWidth = 1800;
        const int minHeight = 800;
        const int minWidth = 400;

        Window.X = 0;
        Window.Y = 100;

        Window.Width = newWidth;
        Window.Height = newHeight;

        Window.MinimumHeight = minHeight;
        Window.MinimumWidth = minWidth;

        return Window;
    }
}
